@@ -113,6 +113,9 @@ vips_conv_build( VipsObject *object )
 		g_assert_not_reached();
 	}
 
+	vips_reorder_margin_hint( convolution->out, 
+		convolution->M->Xsize * convolution->M->Ysize );
+
 	return( 0 );
 }
 
