@@ -81,6 +81,14 @@ typedef enum {
 	VIPS_ANGLE45_LAST
 } VipsAngle45;
 
+typedef enum {
+	VIPS_INTERESTING_NONE,
+	VIPS_INTERESTING_CENTRE,
+	VIPS_INTERESTING_ENTROPY,
+	VIPS_INTERESTING_ATTENTION,
+	VIPS_INTERESTING_LAST
+} VipsInteresting;
+
 int vips_copy( VipsImage *in, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_tilecache( VipsImage *in, VipsImage **out, ... )
@@ -113,6 +121,8 @@ int vips_extract_area( VipsImage *in, VipsImage **out,
 int vips_crop( VipsImage *in, VipsImage **out, 
 	int left, int top, int width, int height, ... )
 	__attribute__((sentinel));
+int vips_smartcrop( VipsImage *in, VipsImage **out, int width, int height, ... )
+	__attribute__((sentinel));
 int vips_extract_band( VipsImage *in, VipsImage **out, int band, ... )
 	__attribute__((sentinel));
 int vips_replicate( VipsImage *in, VipsImage **out, int across, int down, ... )
@@ -124,6 +134,12 @@ int vips_wrap( VipsImage *in, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_rot( VipsImage *in, VipsImage **out, VipsAngle angle, ... )
 	__attribute__((sentinel));
+int vips_rot90( VipsImage *in, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_rot180( VipsImage *in, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_rot270( VipsImage *in, VipsImage **out, ... )
+	__attribute__((sentinel));
 int vips_rot45( VipsImage *in, VipsImage **out, ... )
 	__attribute__((sentinel));
 VipsAngle vips_autorot_get_angle( VipsImage *image );
